# eric7.RemoteServerInterface.EricServerProfilesDialog

Module implementing a dialog to manage server connection profiles.

### Global Attributes

None

### Classes

EricServerProfilesDialog | Class implementing a dialog to manage server connection profiles.

### Functions

None

## EricServerProfilesDialog

Class implementing a dialog to manage server connection profiles.

### Derived from

QDialog, Ui_EricServerProfilesDialog

### Class Attributes

None

### Class Methods

None

### Methods

EricServerProfilesDialog | Constructor
__getProfilesList | Private method to get the list of defined profile names.
__populateProfilesList | Private method to (re-) populate the list of server connection profiles.
getConnectionProfiles | Public method to get the configured connection profiles.
on_addButton_clicked | Private slot add a new connection profile.
on_connectionsList_itemSelectionChanged | Private slot to handle a change of selected items.
on_editButton_clicked | Private slot to edit the selected entry.
on_removeButton_clicked | Private slot to remove the selected connection profiles.
on_resetButton_clicked | Private slot to reset all changes performed.

### Static Methods

None

#### EricServerProfilesDialog (Constructor)

EricServerProfilesDialog(profiles, parent=None)

Constructor

profiles (dict)
  dictionary containing the server connection profiles
parent (QWidget (optional))
  reference to the parent widget (defaults to None)

#### EricServerProfilesDialog.__getProfilesList

__getProfilesList()

Private method to get the list of defined profile names.

Return:
  list of defined profile names

Return Type:
  list of str

#### EricServerProfilesDialog.__populateProfilesList

__populateProfilesList()

Private method to (re-) populate the list of server connection profiles.

#### EricServerProfilesDialog.getConnectionProfiles

getConnectionProfiles()

Public method to get the configured connection profiles.

Return:
  dictionary containing the configured connection profiles

Return Type:
  dict

#### EricServerProfilesDialog.on_addButton_clicked

on_addButton_clicked()

Private slot add a new connection profile.

#### EricServerProfilesDialog.on_connectionsList_itemSelectionChanged

on_connectionsList_itemSelectionChanged()

Private slot to handle a change of selected items.

#### EricServerProfilesDialog.on_editButton_clicked

on_editButton_clicked()

Private slot to edit the selected entry.

#### EricServerProfilesDialog.on_removeButton_clicked

on_removeButton_clicked()

Private slot to remove the selected connection profiles.

#### EricServerProfilesDialog.on_resetButton_clicked

on_resetButton_clicked()

Private slot to reset all changes performed.

Up